name = "version"
__version__ = "0.2.20"

__requirements__ = [
    "pydantic",
    "requests",
    "numpy",
    "torch",
    "sentence-transformers",
    "fastapi",
    "uvicorn",
    "PyYaml",
    "openai>=1.0",
    "tiktoken",
    "google-auth",
    "google-cloud-aiplatform",
    "langchain",
    "anthropic>=0.3.0",
    "python-dotenv",
    "cohere",
    "tokenizer",
]
